@@ -1,10 +1,10 @@
 package Net::DNS::Packet;
 
 #
-# $Id: Packet.pm 1143 2013-12-16 15:19:51Z willem $
+# $Id: Packet.pm 1158 2014-01-10 22:30:40Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1143 $)[1];
+$VERSION = (qw$LastChangedRevision: 1158 $)[1];
 
 
 =head1 NAME
@@ -226,7 +226,7 @@ represents the header section of the packet.
 
 sub header {
 	my $self = shift;
-	return bless \$self, qw(Net::DNS::Header);
+	return bless \$self, q(Net::DNS::Header);
 }
 
 
@@ -864,23 +864,12 @@ sub truncate {
 
 ########################################
 
-use vars qw($AUTOLOAD);
-
-sub AUTOLOAD {				## Default method
-	no strict;
-	@_ = ("method $AUTOLOAD undefined");
-	goto &{'Carp::confess'};
-}
-
-sub DESTROY { }				## Avoid tickling AUTOLOAD (in cleanup)
-
-
 sub dump {				## print internal data structure
-	use Data::Dumper;
+	require Data::Dumper;
 	$Data::Dumper::Sortkeys = sub { return [sort keys %{$_[0]}] };
 	my $self = shift;
-	return Dumper($self) if defined wantarray;
-	print Dumper($self);
+	return Data::Dumper::Dumper($self) if defined wantarray;
+	print Data::Dumper::Dumper($self);
 }
 
 
@@ -895,6 +884,17 @@ sub sigrr {				## obtain packet signature RR
 }
 
 
+sub DESTROY { }				## Avoid tickling AUTOLOAD (in cleanup)
+
+use vars qw($AUTOLOAD);
+
+sub AUTOLOAD {				## Default method
+	no strict;
+	@_ = ("method $AUTOLOAD undefined");
+	goto &{'Carp::confess'};
+}
+
+
 1;
 __END__
 
